ref: 0ffcce55b2dc0c83c1830b26ef6c5a936b507497
parent: ea1df5910952e12c2907b9443228f89a3605d096
author: glenda <glenda@cpre431>
date: Sun Oct 28 14:44:02 EDT 2018
add syscall table to global namespace
--- a/main.c
+++ b/main.c
@@ -14,7 +14,6 @@
{
int nrounds = -1;
int i;
- List syscalls;
ARGBEGIN{
case 'n':
--- a/fuzz.h
+++ b/fuzz.h
@@ -2,6 +2,9 @@
#define FUZZ_H
#include "list.h"
+// Number of calls in enum calls
+#define NCALLS 65
+
/*
For full list of syscalls:
@@ -89,8 +92,12 @@
call c; // System call in use
char* name; // Real name of syscall
int round; // Last run executed
- List inputs; // List of input types in order from left→right
+ int seed; // Seed call was initialized with
+// List inputs; // List of input types in order from left→right
};
+
+// Index of system calls -- one for each enum'd system call
+caller syscalls[NCALLS];
/* == Function prototypes == */